| pbc | R Documentation |
This dataset is obtained from 'pbc' in package 'survival' by excluding the non-randomized individuals. For background and details of the original dataset, please refer to the document page of 'survival'.
pbc
pbcA data frame with 258 rows and 3 columns:
the survival of each subject in the trial (days)
censoring indicator (1: dead; 0: censored)
treatment arm (1: D-penicillamine; 0: placebo)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.